import Config

# Important: indicate date of last release, to generate a changelog for issues closed since then
changelog_issues_closed_after = "2022-08-30"

config :bonfire,
  # Note: you can run `Bonfire.Common.Config.put(:experimental_features_enabled, true)` to enable these in prod too
  experimental_features_enabled: true,
  # low limit so it is easier to test
  default_pagination_limit: 10

# config :pseudo_gettext, :locale, "en-pseudo_text" # uncomment to use https://en.wikipedia.org/wiki/Pseudolocalization and check that the app is properly localisable

config :bonfire, Bonfire.Common.Repo,
  database: System.get_env("POSTGRES_DB", "bonfire_dev"),
  # show_sensitive_data_on_connection_error: true,
  pool_size: String.to_integer(System.get_env("POOL_SIZE") || "10"),
  log: false

path_dep_dirs =
  Mess.deps([path: "deps.path"], [])
  |> Enum.map(&(Keyword.fetch!(elem(&1, 1), :path) <> "/lib"))

config :phoenix_live_reload,
  # watch the app's lib/ dir + the dep/lib/ dir of every locally-cloned dep
  dirs: path_dep_dirs ++ ["lib/"]

# to include cloned code in patterns
path_dep_patterns = Enum.map(path_dep_dirs, &(String.slice(&1, 2..1000) <> ".*ex"))

# Surface views
path_dep_patterns =
  (path_dep_patterns ++ path_dep_dirs)
  |> Enum.map(&(String.slice(&1, 2..1000) <> ".*sface"))

# Watch static and templates for browser reloading.
config :bonfire, Bonfire.Web.Endpoint,
  server: true,
  # In the development environment, Phoenix will debug errors by default, showing us a very informative debugging page. If we want to see what the application would serve in production, set to false
  debug_errors: true,
  check_origin: false,
  code_reloader: true,
  watchers: [
    # yarn: [
    #   "watch",
    #   cd: Path.expand("assets", File.cwd!())
    # ],
    yarn: [
      "watch.js",
      cd: Path.expand("assets", File.cwd!())
    ],
    yarn: [
      "watch.css",
      cd: Path.expand("assets", File.cwd!())
    ],
    yarn: [
      "watch.assets",
      cd: Path.expand("assets", File.cwd!())
    ]
  ],
  live_reload: [
    patterns:
      [
        # ~r"^priv/static/.*(js|css|png|jpeg|jpg|gif|svg)$",
        # ~r"^priv/gettext/.*(po)$",
        # ~r"^web/(live|views)/.*ex$",
        # ~r"^lib/.*_live\.ex$",
        # ~r".*leex$",
        # defp elixirc_paths(:dev), do: ["lib"] ++ catalogues()

        ~r"lib/.*(ex|sface)$",
        ~r"priv/catalogue/.*(ex)$"
      ] ++ path_dep_patterns
  ]

config :logger, :console,
  level: :debug,
  truncate: :infinity,
  # Do not include metadata or timestamps
  format: "[$level] $message\n"

config :phoenix, :stacktrace_depth, 30

config :phoenix, :plug_init_mode, :runtime

config :surface, :compiler, warn_on_undefined_props: true

config :exsync,
  src_monitor: true,
  extra_extensions: [".leex", ".heex", ".js", ".css", ".sface"]

config :versioce, :changelog,
  # Or your own datagrabber module
  datagrabber: Versioce.Changelog.DataGrabber.Git,
  # Or your own formatter module
  formatter: Versioce.Changelog.Formatter.Keepachangelog

config :versioce, :changelog,
  closed_after: changelog_issues_closed_after,
  changelog_file: "docs/CHANGELOG-autogenerated.md",
  datagrabber: Bonfire.Common.Changelog.Github.DataGrabber,
  anchors: %{
    added: ["Feature"],
    changed: ["Improvement", "UI/UX", "Refactor"],
    deprecated: ["[DEP]"],
    removed: ["[REM]"],
    fixed: ["Bug"],
    security: ["Security", "Safety"]
  }
